# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AlertManagerContactPoint',
    'CockpitEndpoint',
    'CockpitPushUrl',
    'ExporterDatadogDestination',
    'ExporterOtlpDestination',
    'TokenScopes',
    'GetExporterDatadogDestinationResult',
    'GetExporterOtlpDestinationResult',
    'GetInstanceEndpointResult',
    'GetInstancePushUrlResult',
    'GetPreconfiguredAlertAlertResult',
    'GetProductsProductResult',
    'GetSourcesSourceResult',
]

@pulumi.output_type
class AlertManagerContactPoint(dict):
    def __init__(__self__, *,
                 email: Optional[_builtins.str] = None):
        """
        :param _builtins.str email: Email addresses for the alert receivers
        """
        if email is not None:
            pulumi.set(__self__, "email", email)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[_builtins.str]:
        """
        Email addresses for the alert receivers
        """
        return pulumi.get(self, "email")


@pulumi.output_type
class CockpitEndpoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "alertmanagerUrl":
            suggest = "alertmanager_url"
        elif key == "grafanaUrl":
            suggest = "grafana_url"
        elif key == "logsUrl":
            suggest = "logs_url"
        elif key == "metricsUrl":
            suggest = "metrics_url"
        elif key == "tracesUrl":
            suggest = "traces_url"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CockpitEndpoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CockpitEndpoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CockpitEndpoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 alertmanager_url: Optional[_builtins.str] = None,
                 grafana_url: Optional[_builtins.str] = None,
                 logs_url: Optional[_builtins.str] = None,
                 metrics_url: Optional[_builtins.str] = None,
                 traces_url: Optional[_builtins.str] = None):
        """
        :param _builtins.str alertmanager_url: (Deprecated) URL for the [Alert manager](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#alert-manager).
        :param _builtins.str grafana_url: (Deprecated) URL for Grafana.
        :param _builtins.str logs_url: (Deprecated) URL for [logs](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#logs) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        :param _builtins.str metrics_url: (Deprecated) URL for [metrics](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#metric) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        :param _builtins.str traces_url: (Deprecated) URL for [traces](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#traces) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        if alertmanager_url is not None:
            pulumi.set(__self__, "alertmanager_url", alertmanager_url)
        if grafana_url is not None:
            pulumi.set(__self__, "grafana_url", grafana_url)
        if logs_url is not None:
            pulumi.set(__self__, "logs_url", logs_url)
        if metrics_url is not None:
            pulumi.set(__self__, "metrics_url", metrics_url)
        if traces_url is not None:
            pulumi.set(__self__, "traces_url", traces_url)

    @_builtins.property
    @pulumi.getter(name="alertmanagerUrl")
    def alertmanager_url(self) -> Optional[_builtins.str]:
        """
        (Deprecated) URL for the [Alert manager](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#alert-manager).
        """
        return pulumi.get(self, "alertmanager_url")

    @_builtins.property
    @pulumi.getter(name="grafanaUrl")
    def grafana_url(self) -> Optional[_builtins.str]:
        """
        (Deprecated) URL for Grafana.
        """
        return pulumi.get(self, "grafana_url")

    @_builtins.property
    @pulumi.getter(name="logsUrl")
    def logs_url(self) -> Optional[_builtins.str]:
        """
        (Deprecated) URL for [logs](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#logs) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        return pulumi.get(self, "logs_url")

    @_builtins.property
    @pulumi.getter(name="metricsUrl")
    def metrics_url(self) -> Optional[_builtins.str]:
        """
        (Deprecated) URL for [metrics](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#metric) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        return pulumi.get(self, "metrics_url")

    @_builtins.property
    @pulumi.getter(name="tracesUrl")
    def traces_url(self) -> Optional[_builtins.str]:
        """
        (Deprecated) URL for [traces](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#traces) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        return pulumi.get(self, "traces_url")


@pulumi.output_type
class CockpitPushUrl(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "pushLogsUrl":
            suggest = "push_logs_url"
        elif key == "pushMetricsUrl":
            suggest = "push_metrics_url"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CockpitPushUrl. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CockpitPushUrl.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CockpitPushUrl.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 push_logs_url: Optional[_builtins.str] = None,
                 push_metrics_url: Optional[_builtins.str] = None):
        """
        :param _builtins.str push_logs_url: Push URL for logs (Grafana Loki)
        :param _builtins.str push_metrics_url: Push URL for metrics (Grafana Mimir)
        """
        if push_logs_url is not None:
            pulumi.set(__self__, "push_logs_url", push_logs_url)
        if push_metrics_url is not None:
            pulumi.set(__self__, "push_metrics_url", push_metrics_url)

    @_builtins.property
    @pulumi.getter(name="pushLogsUrl")
    def push_logs_url(self) -> Optional[_builtins.str]:
        """
        Push URL for logs (Grafana Loki)
        """
        return pulumi.get(self, "push_logs_url")

    @_builtins.property
    @pulumi.getter(name="pushMetricsUrl")
    def push_metrics_url(self) -> Optional[_builtins.str]:
        """
        Push URL for metrics (Grafana Mimir)
        """
        return pulumi.get(self, "push_metrics_url")


@pulumi.output_type
class ExporterDatadogDestination(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "apiKey":
            suggest = "api_key"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ExporterDatadogDestination. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ExporterDatadogDestination.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ExporterDatadogDestination.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 api_key: _builtins.str,
                 endpoint: Optional[_builtins.str] = None):
        """
        :param _builtins.str api_key: Datadog API key. Sensitive.
        :param _builtins.str endpoint: Datadog endpoint URL. Defaults to `https://api.datadoghq.com`.
        """
        pulumi.set(__self__, "api_key", api_key)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> _builtins.str:
        """
        Datadog API key. Sensitive.
        """
        return pulumi.get(self, "api_key")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> Optional[_builtins.str]:
        """
        Datadog endpoint URL. Defaults to `https://api.datadoghq.com`.
        """
        return pulumi.get(self, "endpoint")


@pulumi.output_type
class ExporterOtlpDestination(dict):
    def __init__(__self__, *,
                 endpoint: _builtins.str,
                 headers: Optional[Mapping[str, _builtins.str]] = None):
        """
        :param _builtins.str endpoint: OTLP endpoint URL.
        :param Mapping[str, _builtins.str] headers: Headers to include in requests.
        """
        pulumi.set(__self__, "endpoint", endpoint)
        if headers is not None:
            pulumi.set(__self__, "headers", headers)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        OTLP endpoint URL.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def headers(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        Headers to include in requests.
        """
        return pulumi.get(self, "headers")


@pulumi.output_type
class TokenScopes(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "queryLogs":
            suggest = "query_logs"
        elif key == "queryMetrics":
            suggest = "query_metrics"
        elif key == "queryTraces":
            suggest = "query_traces"
        elif key == "setupAlerts":
            suggest = "setup_alerts"
        elif key == "setupLogsRules":
            suggest = "setup_logs_rules"
        elif key == "setupMetricsRules":
            suggest = "setup_metrics_rules"
        elif key == "writeLogs":
            suggest = "write_logs"
        elif key == "writeMetrics":
            suggest = "write_metrics"
        elif key == "writeTraces":
            suggest = "write_traces"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TokenScopes. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TokenScopes.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TokenScopes.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 query_logs: Optional[_builtins.bool] = None,
                 query_metrics: Optional[_builtins.bool] = None,
                 query_traces: Optional[_builtins.bool] = None,
                 setup_alerts: Optional[_builtins.bool] = None,
                 setup_logs_rules: Optional[_builtins.bool] = None,
                 setup_metrics_rules: Optional[_builtins.bool] = None,
                 write_logs: Optional[_builtins.bool] = None,
                 write_metrics: Optional[_builtins.bool] = None,
                 write_traces: Optional[_builtins.bool] = None):
        """
        :param _builtins.bool query_logs: Permission to query logs.
        :param _builtins.bool query_metrics: Permission to query metrics.
        :param _builtins.bool query_traces: Permission to query traces.
        :param _builtins.bool setup_alerts: Permission to set up alerts.
        :param _builtins.bool setup_logs_rules: Permission to set up logs rules.
        :param _builtins.bool setup_metrics_rules: Permission to set up metrics rules.
        :param _builtins.bool write_logs: Permission to write logs.
        :param _builtins.bool write_metrics: Permission to write metrics.
        :param _builtins.bool write_traces: Permission to write traces.
        """
        if query_logs is not None:
            pulumi.set(__self__, "query_logs", query_logs)
        if query_metrics is not None:
            pulumi.set(__self__, "query_metrics", query_metrics)
        if query_traces is not None:
            pulumi.set(__self__, "query_traces", query_traces)
        if setup_alerts is not None:
            pulumi.set(__self__, "setup_alerts", setup_alerts)
        if setup_logs_rules is not None:
            pulumi.set(__self__, "setup_logs_rules", setup_logs_rules)
        if setup_metrics_rules is not None:
            pulumi.set(__self__, "setup_metrics_rules", setup_metrics_rules)
        if write_logs is not None:
            pulumi.set(__self__, "write_logs", write_logs)
        if write_metrics is not None:
            pulumi.set(__self__, "write_metrics", write_metrics)
        if write_traces is not None:
            pulumi.set(__self__, "write_traces", write_traces)

    @_builtins.property
    @pulumi.getter(name="queryLogs")
    def query_logs(self) -> Optional[_builtins.bool]:
        """
        Permission to query logs.
        """
        return pulumi.get(self, "query_logs")

    @_builtins.property
    @pulumi.getter(name="queryMetrics")
    def query_metrics(self) -> Optional[_builtins.bool]:
        """
        Permission to query metrics.
        """
        return pulumi.get(self, "query_metrics")

    @_builtins.property
    @pulumi.getter(name="queryTraces")
    def query_traces(self) -> Optional[_builtins.bool]:
        """
        Permission to query traces.
        """
        return pulumi.get(self, "query_traces")

    @_builtins.property
    @pulumi.getter(name="setupAlerts")
    def setup_alerts(self) -> Optional[_builtins.bool]:
        """
        Permission to set up alerts.
        """
        return pulumi.get(self, "setup_alerts")

    @_builtins.property
    @pulumi.getter(name="setupLogsRules")
    def setup_logs_rules(self) -> Optional[_builtins.bool]:
        """
        Permission to set up logs rules.
        """
        return pulumi.get(self, "setup_logs_rules")

    @_builtins.property
    @pulumi.getter(name="setupMetricsRules")
    def setup_metrics_rules(self) -> Optional[_builtins.bool]:
        """
        Permission to set up metrics rules.
        """
        return pulumi.get(self, "setup_metrics_rules")

    @_builtins.property
    @pulumi.getter(name="writeLogs")
    def write_logs(self) -> Optional[_builtins.bool]:
        """
        Permission to write logs.
        """
        return pulumi.get(self, "write_logs")

    @_builtins.property
    @pulumi.getter(name="writeMetrics")
    def write_metrics(self) -> Optional[_builtins.bool]:
        """
        Permission to write metrics.
        """
        return pulumi.get(self, "write_metrics")

    @_builtins.property
    @pulumi.getter(name="writeTraces")
    def write_traces(self) -> Optional[_builtins.bool]:
        """
        Permission to write traces.
        """
        return pulumi.get(self, "write_traces")


@pulumi.output_type
class GetExporterDatadogDestinationResult(dict):
    def __init__(__self__, *,
                 api_key: _builtins.str,
                 endpoint: _builtins.str):
        """
        :param _builtins.str api_key: Datadog API key
        :param _builtins.str endpoint: Datadog endpoint URL
        """
        pulumi.set(__self__, "api_key", api_key)
        pulumi.set(__self__, "endpoint", endpoint)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> _builtins.str:
        """
        Datadog API key
        """
        return pulumi.get(self, "api_key")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        Datadog endpoint URL
        """
        return pulumi.get(self, "endpoint")


@pulumi.output_type
class GetExporterOtlpDestinationResult(dict):
    def __init__(__self__, *,
                 endpoint: _builtins.str,
                 headers: Mapping[str, _builtins.str]):
        """
        :param _builtins.str endpoint: OTLP endpoint URL
        :param Mapping[str, _builtins.str] headers: Headers to include in requests
        """
        pulumi.set(__self__, "endpoint", endpoint)
        pulumi.set(__self__, "headers", headers)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        OTLP endpoint URL
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def headers(self) -> Mapping[str, _builtins.str]:
        """
        Headers to include in requests
        """
        return pulumi.get(self, "headers")


@pulumi.output_type
class GetInstanceEndpointResult(dict):
    def __init__(__self__, *,
                 alertmanager_url: _builtins.str,
                 grafana_url: _builtins.str,
                 logs_url: _builtins.str,
                 metrics_url: _builtins.str,
                 traces_url: _builtins.str):
        """
        :param _builtins.str alertmanager_url: (Deprecated) URL for the [Alert manager](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#alert-manager).
        :param _builtins.str grafana_url: (Deprecated) URL for Grafana.
        :param _builtins.str logs_url: (Deprecated) URL for [logs](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#logs) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        :param _builtins.str metrics_url: (Deprecated) URL for [metrics](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#metric) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        :param _builtins.str traces_url: The traces URL.
        """
        pulumi.set(__self__, "alertmanager_url", alertmanager_url)
        pulumi.set(__self__, "grafana_url", grafana_url)
        pulumi.set(__self__, "logs_url", logs_url)
        pulumi.set(__self__, "metrics_url", metrics_url)
        pulumi.set(__self__, "traces_url", traces_url)

    @_builtins.property
    @pulumi.getter(name="alertmanagerUrl")
    def alertmanager_url(self) -> _builtins.str:
        """
        (Deprecated) URL for the [Alert manager](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#alert-manager).
        """
        return pulumi.get(self, "alertmanager_url")

    @_builtins.property
    @pulumi.getter(name="grafanaUrl")
    def grafana_url(self) -> _builtins.str:
        """
        (Deprecated) URL for Grafana.
        """
        return pulumi.get(self, "grafana_url")

    @_builtins.property
    @pulumi.getter(name="logsUrl")
    def logs_url(self) -> _builtins.str:
        """
        (Deprecated) URL for [logs](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#logs) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        return pulumi.get(self, "logs_url")

    @_builtins.property
    @pulumi.getter(name="metricsUrl")
    def metrics_url(self) -> _builtins.str:
        """
        (Deprecated) URL for [metrics](https://www.scaleway.com/en/docs/observability/cockpit/concepts/#metric) to retrieve in the [Data sources tab](https://console.scaleway.com/cockpit/dataSource) of the Scaleway console.
        """
        return pulumi.get(self, "metrics_url")

    @_builtins.property
    @pulumi.getter(name="tracesUrl")
    def traces_url(self) -> _builtins.str:
        """
        The traces URL.
        """
        return pulumi.get(self, "traces_url")


@pulumi.output_type
class GetInstancePushUrlResult(dict):
    def __init__(__self__, *,
                 push_logs_url: _builtins.str,
                 push_metrics_url: _builtins.str):
        """
        :param _builtins.str push_logs_url: Push URL for logs (Grafana Loki)
        :param _builtins.str push_metrics_url: Push URL for metrics (Grafana Mimir)
        """
        pulumi.set(__self__, "push_logs_url", push_logs_url)
        pulumi.set(__self__, "push_metrics_url", push_metrics_url)

    @_builtins.property
    @pulumi.getter(name="pushLogsUrl")
    def push_logs_url(self) -> _builtins.str:
        """
        Push URL for logs (Grafana Loki)
        """
        return pulumi.get(self, "push_logs_url")

    @_builtins.property
    @pulumi.getter(name="pushMetricsUrl")
    def push_metrics_url(self) -> _builtins.str:
        """
        Push URL for metrics (Grafana Mimir)
        """
        return pulumi.get(self, "push_metrics_url")


@pulumi.output_type
class GetPreconfiguredAlertAlertResult(dict):
    def __init__(__self__, *,
                 annotations: Mapping[str, _builtins.str],
                 data_source_id: _builtins.str,
                 display_description: _builtins.str,
                 display_name: _builtins.str,
                 duration: _builtins.str,
                 name: _builtins.str,
                 preconfigured_rule_id: _builtins.str,
                 product_family: _builtins.str,
                 product_name: _builtins.str,
                 rule: _builtins.str,
                 rule_status: _builtins.str,
                 state: _builtins.str):
        """
        :param Mapping[str, _builtins.str] annotations: Map of annotations attached to the alert.
        :param _builtins.str data_source_id: Filter alerts by data source ID.
        :param _builtins.str display_description: Human-readable description of the alert.
        :param _builtins.str display_name: Human-readable name of the alert.
        :param _builtins.str duration: Duration for which the condition must be true before the alert fires (e.g., "5m").
        :param _builtins.str name: Name of the alert rule.
        :param _builtins.str preconfigured_rule_id: Unique identifier of the preconfigured rule. Use this ID in `observability.AlertManager` resource.
        :param _builtins.str product_family: Family of the product (e.g., "compute", "storage", "network").
        :param _builtins.str product_name: Scaleway product associated with the alert (e.g., "instance", "rdb", "kubernetes").
        :param _builtins.str rule: PromQL expression defining the alert condition.
        :param _builtins.str rule_status: Filter alerts by rule status. Valid values are `enabled` or `disabled`.
        :param _builtins.str state: Current state of the alert (`inactive`, `pending`, `firing`).
        """
        pulumi.set(__self__, "annotations", annotations)
        pulumi.set(__self__, "data_source_id", data_source_id)
        pulumi.set(__self__, "display_description", display_description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "preconfigured_rule_id", preconfigured_rule_id)
        pulumi.set(__self__, "product_family", product_family)
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "rule", rule)
        pulumi.set(__self__, "rule_status", rule_status)
        pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter
    def annotations(self) -> Mapping[str, _builtins.str]:
        """
        Map of annotations attached to the alert.
        """
        return pulumi.get(self, "annotations")

    @_builtins.property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> _builtins.str:
        """
        Filter alerts by data source ID.
        """
        return pulumi.get(self, "data_source_id")

    @_builtins.property
    @pulumi.getter(name="displayDescription")
    def display_description(self) -> _builtins.str:
        """
        Human-readable description of the alert.
        """
        return pulumi.get(self, "display_description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        Human-readable name of the alert.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def duration(self) -> _builtins.str:
        """
        Duration for which the condition must be true before the alert fires (e.g., "5m").
        """
        return pulumi.get(self, "duration")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the alert rule.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="preconfiguredRuleId")
    def preconfigured_rule_id(self) -> _builtins.str:
        """
        Unique identifier of the preconfigured rule. Use this ID in `observability.AlertManager` resource.
        """
        return pulumi.get(self, "preconfigured_rule_id")

    @_builtins.property
    @pulumi.getter(name="productFamily")
    def product_family(self) -> _builtins.str:
        """
        Family of the product (e.g., "compute", "storage", "network").
        """
        return pulumi.get(self, "product_family")

    @_builtins.property
    @pulumi.getter(name="productName")
    def product_name(self) -> _builtins.str:
        """
        Scaleway product associated with the alert (e.g., "instance", "rdb", "kubernetes").
        """
        return pulumi.get(self, "product_name")

    @_builtins.property
    @pulumi.getter
    def rule(self) -> _builtins.str:
        """
        PromQL expression defining the alert condition.
        """
        return pulumi.get(self, "rule")

    @_builtins.property
    @pulumi.getter(name="ruleStatus")
    def rule_status(self) -> _builtins.str:
        """
        Filter alerts by rule status. Valid values are `enabled` or `disabled`.
        """
        return pulumi.get(self, "rule_status")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        Current state of the alert (`inactive`, `pending`, `firing`).
        """
        return pulumi.get(self, "state")


@pulumi.output_type
class GetProductsProductResult(dict):
    def __init__(__self__, *,
                 display_name: _builtins.str,
                 family_name: _builtins.str,
                 name: _builtins.str):
        """
        :param _builtins.str display_name: Human-readable display name of the product.
        :param _builtins.str family_name: Product family name.
        :param _builtins.str name: Product name to use in exported_products (e.g. cockpit, LB, object-storage).
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "family_name", family_name)
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        Human-readable display name of the product.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="familyName")
    def family_name(self) -> _builtins.str:
        """
        Product family name.
        """
        return pulumi.get(self, "family_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Product name to use in exported_products (e.g. cockpit, LB, object-storage).
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetSourcesSourceResult(dict):
    def __init__(__self__, *,
                 created_at: _builtins.str,
                 id: _builtins.str,
                 name: _builtins.str,
                 origin: _builtins.str,
                 project_id: _builtins.str,
                 push_url: _builtins.str,
                 region: _builtins.str,
                 retention_days: _builtins.int,
                 synchronized_with_grafana: _builtins.bool,
                 type: _builtins.str,
                 updated_at: _builtins.str,
                 url: _builtins.str):
        """
        :param _builtins.str created_at: The date and time of the creation of the cockpit datasource.
        :param _builtins.str id: The ID of the data source.
        :param _builtins.str name: Filter sources by name.
        :param _builtins.str origin: Filter sources by origin. Possible values are: `scaleway`, `custom`.
        :param _builtins.str project_id: The project ID the cockpit sources are associated with.
        :param _builtins.str push_url: The URL endpoint used for pushing data to the cockpit data source.
        :param _builtins.str region: The region in which the cockpit sources are located.
        :param _builtins.int retention_days: The number of days to retain data.
        :param _builtins.bool synchronized_with_grafana: Indicates whether the data source is synchronized with Grafana.
        :param _builtins.str type: Filter sources by type. Possible values are: `metrics`, `logs`, `traces`.
        :param _builtins.str updated_at: The date and time of the last update of the cockpit datasource.
        :param _builtins.str url: The URL of the datasource.
        """
        pulumi.set(__self__, "created_at", created_at)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "origin", origin)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "push_url", push_url)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "retention_days", retention_days)
        pulumi.set(__self__, "synchronized_with_grafana", synchronized_with_grafana)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "updated_at", updated_at)
        pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time of the creation of the cockpit datasource.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the data source.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Filter sources by name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def origin(self) -> _builtins.str:
        """
        Filter sources by origin. Possible values are: `scaleway`, `custom`.
        """
        return pulumi.get(self, "origin")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The project ID the cockpit sources are associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="pushUrl")
    def push_url(self) -> _builtins.str:
        """
        The URL endpoint used for pushing data to the cockpit data source.
        """
        return pulumi.get(self, "push_url")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region in which the cockpit sources are located.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> _builtins.int:
        """
        The number of days to retain data.
        """
        return pulumi.get(self, "retention_days")

    @_builtins.property
    @pulumi.getter(name="synchronizedWithGrafana")
    def synchronized_with_grafana(self) -> _builtins.bool:
        """
        Indicates whether the data source is synchronized with Grafana.
        """
        return pulumi.get(self, "synchronized_with_grafana")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Filter sources by type. Possible values are: `metrics`, `logs`, `traces`.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        The date and time of the last update of the cockpit datasource.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter
    def url(self) -> _builtins.str:
        """
        The URL of the datasource.
        """
        return pulumi.get(self, "url")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstancePolicyArgs', 'InstancePolicy']

@pulumi.input_type
class InstancePolicyArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[_builtins.str],
                 instance_group_id: pulumi.Input[_builtins.str],
                 priority: pulumi.Input[_builtins.int],
                 type: pulumi.Input[_builtins.str],
                 value: pulumi.Input[_builtins.int],
                 metrics: Optional[pulumi.Input[Sequence[pulumi.Input['InstancePolicyMetricArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a InstancePolicy resource.
        :param pulumi.Input[_builtins.str] action: The action to execute when the metric-based condition is met.
        :param pulumi.Input[_builtins.str] instance_group_id: The ID of the Instance group related to this policy.
        :param pulumi.Input[_builtins.int] priority: The priority of this policy compared to all other scaling policies. This determines the processing order. The lower the number, the higher the priority.
        :param pulumi.Input[_builtins.str] type: How to use the number defined in `value` when determining by how many Instances to scale up/down.
        :param pulumi.Input[_builtins.int] value: The value representing the magnitude of the scaling action to take for the Instance group. Depending on the `type` parameter, this number could represent a total number of Instances in the group, a number of Instances to add, or a percentage to scale the group by.
        :param pulumi.Input[Sequence[pulumi.Input['InstancePolicyMetricArgs']]] metrics: Cockpit metric to use when determining whether to trigger a scale up/down action.
        :param pulumi.Input[_builtins.str] name: The Instance policy name.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Instance policy is associated with.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Instance policy exists.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "instance_group_id", instance_group_id)
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Input[_builtins.str]:
        """
        The action to execute when the metric-based condition is met.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter(name="instanceGroupId")
    def instance_group_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Instance group related to this policy.
        """
        return pulumi.get(self, "instance_group_id")

    @instance_group_id.setter
    def instance_group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "instance_group_id", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Input[_builtins.int]:
        """
        The priority of this policy compared to all other scaling policies. This determines the processing order. The lower the number, the higher the priority.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        How to use the number defined in `value` when determining by how many Instances to scale up/down.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Input[_builtins.int]:
        """
        The value representing the magnitude of the scaling action to take for the Instance group. Depending on the `type` parameter, this number could represent a total number of Instances in the group, a number of Instances to add, or a percentage to scale the group by.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter
    def metrics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstancePolicyMetricArgs']]]]:
        """
        Cockpit metric to use when determining whether to trigger a scale up/down action.
        """
        return pulumi.get(self, "metrics")

    @metrics.setter
    def metrics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstancePolicyMetricArgs']]]]):
        pulumi.set(self, "metrics", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Instance policy name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project the Instance policy is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the Instance policy exists.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _InstancePolicyState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 instance_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metrics: Optional[pulumi.Input[Sequence[pulumi.Input['InstancePolicyMetricArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.int]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering InstancePolicy resources.
        :param pulumi.Input[_builtins.str] action: The action to execute when the metric-based condition is met.
        :param pulumi.Input[_builtins.str] instance_group_id: The ID of the Instance group related to this policy.
        :param pulumi.Input[Sequence[pulumi.Input['InstancePolicyMetricArgs']]] metrics: Cockpit metric to use when determining whether to trigger a scale up/down action.
        :param pulumi.Input[_builtins.str] name: The Instance policy name.
        :param pulumi.Input[_builtins.int] priority: The priority of this policy compared to all other scaling policies. This determines the processing order. The lower the number, the higher the priority.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Instance policy is associated with.
        :param pulumi.Input[_builtins.str] type: How to use the number defined in `value` when determining by how many Instances to scale up/down.
        :param pulumi.Input[_builtins.int] value: The value representing the magnitude of the scaling action to take for the Instance group. Depending on the `type` parameter, this number could represent a total number of Instances in the group, a number of Instances to add, or a percentage to scale the group by.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Instance policy exists.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if instance_group_id is not None:
            pulumi.set(__self__, "instance_group_id", instance_group_id)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The action to execute when the metric-based condition is met.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter(name="instanceGroupId")
    def instance_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Instance group related to this policy.
        """
        return pulumi.get(self, "instance_group_id")

    @instance_group_id.setter
    def instance_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "instance_group_id", value)

    @_builtins.property
    @pulumi.getter
    def metrics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstancePolicyMetricArgs']]]]:
        """
        Cockpit metric to use when determining whether to trigger a scale up/down action.
        """
        return pulumi.get(self, "metrics")

    @metrics.setter
    def metrics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstancePolicyMetricArgs']]]]):
        pulumi.set(self, "metrics", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Instance policy name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The priority of this policy compared to all other scaling policies. This determines the processing order. The lower the number, the higher the priority.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project the Instance policy is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        How to use the number defined in `value` when determining by how many Instances to scale up/down.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The value representing the magnitude of the scaling action to take for the Instance group. Depending on the `type` parameter, this number could represent a total number of Instances in the group, a number of Instances to add, or a percentage to scale the group by.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the Instance policy exists.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("scaleway:autoscaling/instancePolicy:InstancePolicy")
class InstancePolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 instance_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metrics: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstancePolicyMetricArgs', 'InstancePolicyMetricArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.int]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Books and manages Autoscaling Instance policies.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        up = scaleway.autoscaling.InstancePolicy("up",
            instance_group_id=main["id"],
            name="scale-up-if-cpu-high",
            action="scale_up",
            type="flat_count",
            value=1,
            priority=1,
            metrics=[{
                "name": "cpu scale up",
                "managed_metric": "managed_metric_instance_cpu",
                "operator": "operator_greater_than",
                "aggregate": "aggregate_average",
                "sampling_range_min": 5,
                "threshold": 70,
            }])
        down = scaleway.autoscaling.InstancePolicy("down",
            instance_group_id=main["id"],
            name="scale-down-if-cpu-low",
            action="scale_down",
            type="flat_count",
            value=1,
            priority=2,
            metrics=[{
                "name": "cpu scale down",
                "managed_metric": "managed_metric_instance_cpu",
                "operator": "operator_less_than",
                "aggregate": "aggregate_average",
                "sampling_range_min": 5,
                "threshold": 40,
            }])
        ```

        ## Import

        Autoscaling instance policies can be imported using `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:autoscaling/instancePolicy:InstancePolicy main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: The action to execute when the metric-based condition is met.
        :param pulumi.Input[_builtins.str] instance_group_id: The ID of the Instance group related to this policy.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InstancePolicyMetricArgs', 'InstancePolicyMetricArgsDict']]]] metrics: Cockpit metric to use when determining whether to trigger a scale up/down action.
        :param pulumi.Input[_builtins.str] name: The Instance policy name.
        :param pulumi.Input[_builtins.int] priority: The priority of this policy compared to all other scaling policies. This determines the processing order. The lower the number, the higher the priority.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Instance policy is associated with.
        :param pulumi.Input[_builtins.str] type: How to use the number defined in `value` when determining by how many Instances to scale up/down.
        :param pulumi.Input[_builtins.int] value: The value representing the magnitude of the scaling action to take for the Instance group. Depending on the `type` parameter, this number could represent a total number of Instances in the group, a number of Instances to add, or a percentage to scale the group by.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Instance policy exists.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstancePolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Books and manages Autoscaling Instance policies.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        up = scaleway.autoscaling.InstancePolicy("up",
            instance_group_id=main["id"],
            name="scale-up-if-cpu-high",
            action="scale_up",
            type="flat_count",
            value=1,
            priority=1,
            metrics=[{
                "name": "cpu scale up",
                "managed_metric": "managed_metric_instance_cpu",
                "operator": "operator_greater_than",
                "aggregate": "aggregate_average",
                "sampling_range_min": 5,
                "threshold": 70,
            }])
        down = scaleway.autoscaling.InstancePolicy("down",
            instance_group_id=main["id"],
            name="scale-down-if-cpu-low",
            action="scale_down",
            type="flat_count",
            value=1,
            priority=2,
            metrics=[{
                "name": "cpu scale down",
                "managed_metric": "managed_metric_instance_cpu",
                "operator": "operator_less_than",
                "aggregate": "aggregate_average",
                "sampling_range_min": 5,
                "threshold": 40,
            }])
        ```

        ## Import

        Autoscaling instance policies can be imported using `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:autoscaling/instancePolicy:InstancePolicy main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param InstancePolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstancePolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 instance_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metrics: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstancePolicyMetricArgs', 'InstancePolicyMetricArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.int]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstancePolicyArgs.__new__(InstancePolicyArgs)

            if action is None and not opts.urn:
                raise TypeError("Missing required property 'action'")
            __props__.__dict__["action"] = action
            if instance_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_group_id'")
            __props__.__dict__["instance_group_id"] = instance_group_id
            __props__.__dict__["metrics"] = metrics
            __props__.__dict__["name"] = name
            if priority is None and not opts.urn:
                raise TypeError("Missing required property 'priority'")
            __props__.__dict__["priority"] = priority
            __props__.__dict__["project_id"] = project_id
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            if value is None and not opts.urn:
                raise TypeError("Missing required property 'value'")
            __props__.__dict__["value"] = value
            __props__.__dict__["zone"] = zone
        super(InstancePolicy, __self__).__init__(
            'scaleway:autoscaling/instancePolicy:InstancePolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[_builtins.str]] = None,
            instance_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            metrics: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstancePolicyMetricArgs', 'InstancePolicyMetricArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            priority: Optional[pulumi.Input[_builtins.int]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            value: Optional[pulumi.Input[_builtins.int]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'InstancePolicy':
        """
        Get an existing InstancePolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: The action to execute when the metric-based condition is met.
        :param pulumi.Input[_builtins.str] instance_group_id: The ID of the Instance group related to this policy.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InstancePolicyMetricArgs', 'InstancePolicyMetricArgsDict']]]] metrics: Cockpit metric to use when determining whether to trigger a scale up/down action.
        :param pulumi.Input[_builtins.str] name: The Instance policy name.
        :param pulumi.Input[_builtins.int] priority: The priority of this policy compared to all other scaling policies. This determines the processing order. The lower the number, the higher the priority.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Instance policy is associated with.
        :param pulumi.Input[_builtins.str] type: How to use the number defined in `value` when determining by how many Instances to scale up/down.
        :param pulumi.Input[_builtins.int] value: The value representing the magnitude of the scaling action to take for the Instance group. Depending on the `type` parameter, this number could represent a total number of Instances in the group, a number of Instances to add, or a percentage to scale the group by.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Instance policy exists.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstancePolicyState.__new__(_InstancePolicyState)

        __props__.__dict__["action"] = action
        __props__.__dict__["instance_group_id"] = instance_group_id
        __props__.__dict__["metrics"] = metrics
        __props__.__dict__["name"] = name
        __props__.__dict__["priority"] = priority
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["type"] = type
        __props__.__dict__["value"] = value
        __props__.__dict__["zone"] = zone
        return InstancePolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Output[_builtins.str]:
        """
        The action to execute when the metric-based condition is met.
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="instanceGroupId")
    def instance_group_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Instance group related to this policy.
        """
        return pulumi.get(self, "instance_group_id")

    @_builtins.property
    @pulumi.getter
    def metrics(self) -> pulumi.Output[Sequence['outputs.InstancePolicyMetric']]:
        """
        Cockpit metric to use when determining whether to trigger a scale up/down action.
        """
        return pulumi.get(self, "metrics")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The Instance policy name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Output[_builtins.int]:
        """
        The priority of this policy compared to all other scaling policies. This determines the processing order. The lower the number, the higher the priority.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the Project the Instance policy is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        How to use the number defined in `value` when determining by how many Instances to scale up/down.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[_builtins.int]:
        """
        The value representing the magnitude of the scaling action to take for the Instance group. Depending on the `type` parameter, this number could represent a total number of Instances in the group, a number of Instances to add, or a percentage to scale the group by.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `zone`) The zone in which the Instance policy exists.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['EdgeServicesDnsStageArgs', 'EdgeServicesDnsStage']

@pulumi.input_type
class EdgeServicesDnsStageArgs:
    def __init__(__self__, *,
                 pipeline_id: pulumi.Input[_builtins.str],
                 backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 fqdns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tls_stage_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a EdgeServicesDnsStage resource.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] backend_stage_id: The backend stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] cache_stage_id: The cache stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] fqdns: Fully Qualified Domain Name (in the format subdomain.example.com) to attach to the stage.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the DNS stage is associated with.
        :param pulumi.Input[_builtins.str] tls_stage_id: The TLS stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        if backend_stage_id is not None:
            pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if cache_stage_id is not None:
            pulumi.set(__self__, "cache_stage_id", cache_stage_id)
        if fqdns is not None:
            pulumi.set(__self__, "fqdns", fqdns)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tls_stage_id is not None:
            pulumi.set(__self__, "tls_stage_id", tls_stage_id)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pipeline_id", value)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The backend stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        return pulumi.get(self, "backend_stage_id")

    @backend_stage_id.setter
    def backend_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend_stage_id", value)

    @_builtins.property
    @pulumi.getter(name="cacheStageId")
    def cache_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cache stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        return pulumi.get(self, "cache_stage_id")

    @cache_stage_id.setter
    def cache_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cache_stage_id", value)

    @_builtins.property
    @pulumi.getter
    def fqdns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Fully Qualified Domain Name (in the format subdomain.example.com) to attach to the stage.
        """
        return pulumi.get(self, "fqdns")

    @fqdns.setter
    def fqdns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "fqdns", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the DNS stage is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="tlsStageId")
    def tls_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The TLS stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        return pulumi.get(self, "tls_stage_id")

    @tls_stage_id.setter
    def tls_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tls_stage_id", value)


@pulumi.input_type
class _EdgeServicesDnsStageState:
    def __init__(__self__, *,
                 backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 default_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
                 fqdns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tls_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EdgeServicesDnsStage resources.
        :param pulumi.Input[_builtins.str] backend_stage_id: The backend stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] cache_stage_id: The cache stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the DNS stage.
        :param pulumi.Input[_builtins.str] default_fqdn: The Default Fully Qualified Domain Name attached to the stage.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] fqdns: Fully Qualified Domain Name (in the format subdomain.example.com) to attach to the stage.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the DNS stage is associated with.
        :param pulumi.Input[_builtins.str] tls_stage_id: The TLS stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] type: The type of the stage.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the DNS stage.
        """
        if backend_stage_id is not None:
            pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if cache_stage_id is not None:
            pulumi.set(__self__, "cache_stage_id", cache_stage_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if default_fqdn is not None:
            pulumi.set(__self__, "default_fqdn", default_fqdn)
        if fqdns is not None:
            pulumi.set(__self__, "fqdns", fqdns)
        if pipeline_id is not None:
            pulumi.set(__self__, "pipeline_id", pipeline_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tls_stage_id is not None:
            pulumi.set(__self__, "tls_stage_id", tls_stage_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The backend stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        return pulumi.get(self, "backend_stage_id")

    @backend_stage_id.setter
    def backend_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend_stage_id", value)

    @_builtins.property
    @pulumi.getter(name="cacheStageId")
    def cache_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cache stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        return pulumi.get(self, "cache_stage_id")

    @cache_stage_id.setter
    def cache_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cache_stage_id", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the DNS stage.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="defaultFqdn")
    def default_fqdn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Default Fully Qualified Domain Name attached to the stage.
        """
        return pulumi.get(self, "default_fqdn")

    @default_fqdn.setter
    def default_fqdn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_fqdn", value)

    @_builtins.property
    @pulumi.getter
    def fqdns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Fully Qualified Domain Name (in the format subdomain.example.com) to attach to the stage.
        """
        return pulumi.get(self, "fqdns")

    @fqdns.setter
    def fqdns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "fqdns", value)

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @pipeline_id.setter
    def pipeline_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the DNS stage is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="tlsStageId")
    def tls_stage_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The TLS stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        return pulumi.get(self, "tls_stage_id")

    @tls_stage_id.setter
    def tls_stage_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tls_stage_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the stage.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the DNS stage.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


warnings.warn("""scaleway.index/edgeservicesdnsstage.EdgeServicesDnsStage has been deprecated in favor of scaleway.edgeservices/dnsstage.DnsStage""", DeprecationWarning)


@pulumi.type_token("scaleway:index/edgeServicesDnsStage:EdgeServicesDnsStage")
class EdgeServicesDnsStage(pulumi.CustomResource):
    warnings.warn("""scaleway.index/edgeservicesdnsstage.EdgeServicesDnsStage has been deprecated in favor of scaleway.edgeservices/dnsstage.DnsStage""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 fqdns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tls_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Edge Services DNS Stages.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.edgeservices.DnsStage("main",
            pipeline_id=main_scaleway_edge_services_pipeline["id"],
            fqdns=["subdomain.example.com"])
        ```

        ## Import

        DNS stages can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/edgeServicesDnsStage:EdgeServicesDnsStage basic 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] backend_stage_id: The backend stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] cache_stage_id: The cache stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] fqdns: Fully Qualified Domain Name (in the format subdomain.example.com) to attach to the stage.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the DNS stage is associated with.
        :param pulumi.Input[_builtins.str] tls_stage_id: The TLS stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EdgeServicesDnsStageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Edge Services DNS Stages.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.edgeservices.DnsStage("main",
            pipeline_id=main_scaleway_edge_services_pipeline["id"],
            fqdns=["subdomain.example.com"])
        ```

        ## Import

        DNS stages can be imported using the `{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/edgeServicesDnsStage:EdgeServicesDnsStage basic 11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param EdgeServicesDnsStageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EdgeServicesDnsStageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 fqdns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tls_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""EdgeServicesDnsStage is deprecated: scaleway.index/edgeservicesdnsstage.EdgeServicesDnsStage has been deprecated in favor of scaleway.edgeservices/dnsstage.DnsStage""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EdgeServicesDnsStageArgs.__new__(EdgeServicesDnsStageArgs)

            __props__.__dict__["backend_stage_id"] = backend_stage_id
            __props__.__dict__["cache_stage_id"] = cache_stage_id
            __props__.__dict__["fqdns"] = fqdns
            if pipeline_id is None and not opts.urn:
                raise TypeError("Missing required property 'pipeline_id'")
            __props__.__dict__["pipeline_id"] = pipeline_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tls_stage_id"] = tls_stage_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["default_fqdn"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["updated_at"] = None
        super(EdgeServicesDnsStage, __self__).__init__(
            'scaleway:index/edgeServicesDnsStage:EdgeServicesDnsStage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
            cache_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            default_fqdn: Optional[pulumi.Input[_builtins.str]] = None,
            fqdns: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            pipeline_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tls_stage_id: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'EdgeServicesDnsStage':
        """
        Get an existing EdgeServicesDnsStage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] backend_stage_id: The backend stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] cache_stage_id: The cache stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the DNS stage.
        :param pulumi.Input[_builtins.str] default_fqdn: The Default Fully Qualified Domain Name attached to the stage.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] fqdns: Fully Qualified Domain Name (in the format subdomain.example.com) to attach to the stage.
        :param pulumi.Input[_builtins.str] pipeline_id: The ID of the pipeline.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the DNS stage is associated with.
        :param pulumi.Input[_builtins.str] tls_stage_id: The TLS stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        :param pulumi.Input[_builtins.str] type: The type of the stage.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the DNS stage.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EdgeServicesDnsStageState.__new__(_EdgeServicesDnsStageState)

        __props__.__dict__["backend_stage_id"] = backend_stage_id
        __props__.__dict__["cache_stage_id"] = cache_stage_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["default_fqdn"] = default_fqdn
        __props__.__dict__["fqdns"] = fqdns
        __props__.__dict__["pipeline_id"] = pipeline_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tls_stage_id"] = tls_stage_id
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_at"] = updated_at
        return EdgeServicesDnsStage(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> pulumi.Output[_builtins.str]:
        """
        The backend stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        return pulumi.get(self, "backend_stage_id")

    @_builtins.property
    @pulumi.getter(name="cacheStageId")
    def cache_stage_id(self) -> pulumi.Output[_builtins.str]:
        """
        The cache stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        return pulumi.get(self, "cache_stage_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the DNS stage.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="defaultFqdn")
    def default_fqdn(self) -> pulumi.Output[_builtins.str]:
        """
        The Default Fully Qualified Domain Name attached to the stage.
        """
        return pulumi.get(self, "default_fqdn")

    @_builtins.property
    @pulumi.getter
    def fqdns(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Fully Qualified Domain Name (in the format subdomain.example.com) to attach to the stage.
        """
        return pulumi.get(self, "fqdns")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the pipeline.
        """
        return pulumi.get(self, "pipeline_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the DNS stage is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="tlsStageId")
    def tls_stage_id(self) -> pulumi.Output[_builtins.str]:
        """
        The TLS stage ID the DNS stage will be linked to. Only one of `backend_stage_id`, `cache_stage_id` and `tls_stage_id` should be specified.
        """
        return pulumi.get(self, "tls_stage_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the stage.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the DNS stage.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetBucketPolicyResult',
    'AwaitableGetBucketPolicyResult',
    'get_bucket_policy',
    'get_bucket_policy_output',
]

@pulumi.output_type
class GetBucketPolicyResult:
    """
    A collection of values returned by getBucketPolicy.
    """
    def __init__(__self__, bucket=None, id=None, policy=None, project_id=None, region=None):
        if bucket and not isinstance(bucket, str):
            raise TypeError("Expected argument 'bucket' to be a str")
        pulumi.set(__self__, "bucket", bucket)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if policy and not isinstance(policy, str):
            raise TypeError("Expected argument 'policy' to be a str")
        pulumi.set(__self__, "policy", policy)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> _builtins.str:
        return pulumi.get(self, "bucket")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def policy(self) -> _builtins.str:
        """
        The content of the bucket policy in JSON format.
        """
        return pulumi.get(self, "policy")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")


class AwaitableGetBucketPolicyResult(GetBucketPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBucketPolicyResult(
            bucket=self.bucket,
            id=self.id,
            policy=self.policy,
            project_id=self.project_id,
            region=self.region)


def get_bucket_policy(bucket: Optional[_builtins.str] = None,
                      project_id: Optional[_builtins.str] = None,
                      region: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBucketPolicyResult:
    """
    The `object.BucketPolicy` data source is used to retrieve information about the bucket policy of an Object Storage bucket.

    Refer to the Object Storage [documentation](https://www.scaleway.com/en/docs/object-storage/api-cli/bucket-policy/) for more information.

    ## Retrieve the bucket policy of a bucket

    The following command allows you to retrieve a bucket policy by its bucket.

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    main = scaleway.object.get_bucket_policy(bucket="bucket.test.com")
    ```


    :param _builtins.str bucket: The name of the bucket.
    :param _builtins.str region: `region`) The region in which the Object Storage exists.
    """
    __args__ = dict()
    __args__['bucket'] = bucket
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:object/getBucketPolicy:getBucketPolicy', __args__, opts=opts, typ=GetBucketPolicyResult).value

    return AwaitableGetBucketPolicyResult(
        bucket=pulumi.get(__ret__, 'bucket'),
        id=pulumi.get(__ret__, 'id'),
        policy=pulumi.get(__ret__, 'policy'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'))
def get_bucket_policy_output(bucket: Optional[pulumi.Input[_builtins.str]] = None,
                             project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBucketPolicyResult]:
    """
    The `object.BucketPolicy` data source is used to retrieve information about the bucket policy of an Object Storage bucket.

    Refer to the Object Storage [documentation](https://www.scaleway.com/en/docs/object-storage/api-cli/bucket-policy/) for more information.

    ## Retrieve the bucket policy of a bucket

    The following command allows you to retrieve a bucket policy by its bucket.

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    main = scaleway.object.get_bucket_policy(bucket="bucket.test.com")
    ```


    :param _builtins.str bucket: The name of the bucket.
    :param _builtins.str region: `region`) The region in which the Object Storage exists.
    """
    __args__ = dict()
    __args__['bucket'] = bucket
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:object/getBucketPolicy:getBucketPolicy', __args__, opts=opts, typ=GetBucketPolicyResult)
    return __ret__.apply(lambda __response__: GetBucketPolicyResult(
        bucket=pulumi.get(__response__, 'bucket'),
        id=pulumi.get(__response__, 'id'),
        policy=pulumi.get(__response__, 'policy'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEventResult',
    'AwaitableGetEventResult',
    'get_event',
    'get_event_output',
]

@pulumi.output_type
class GetEventResult:
    """
    A collection of values returned by getEvent.
    """
    def __init__(__self__, events=None, id=None, method_name=None, order_by=None, organization_id=None, principal_id=None, product_name=None, project_id=None, recorded_after=None, recorded_before=None, region=None, resource_id=None, resource_type=None, service_name=None, source_ip=None, status=None):
        if events and not isinstance(events, list):
            raise TypeError("Expected argument 'events' to be a list")
        pulumi.set(__self__, "events", events)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if method_name and not isinstance(method_name, str):
            raise TypeError("Expected argument 'method_name' to be a str")
        pulumi.set(__self__, "method_name", method_name)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if principal_id and not isinstance(principal_id, str):
            raise TypeError("Expected argument 'principal_id' to be a str")
        pulumi.set(__self__, "principal_id", principal_id)
        if product_name and not isinstance(product_name, str):
            raise TypeError("Expected argument 'product_name' to be a str")
        pulumi.set(__self__, "product_name", product_name)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if recorded_after and not isinstance(recorded_after, str):
            raise TypeError("Expected argument 'recorded_after' to be a str")
        pulumi.set(__self__, "recorded_after", recorded_after)
        if recorded_before and not isinstance(recorded_before, str):
            raise TypeError("Expected argument 'recorded_before' to be a str")
        pulumi.set(__self__, "recorded_before", recorded_before)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        pulumi.set(__self__, "resource_id", resource_id)
        if resource_type and not isinstance(resource_type, str):
            raise TypeError("Expected argument 'resource_type' to be a str")
        pulumi.set(__self__, "resource_type", resource_type)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if source_ip and not isinstance(source_ip, str):
            raise TypeError("Expected argument 'source_ip' to be a str")
        pulumi.set(__self__, "source_ip", source_ip)
        if status and not isinstance(status, int):
            raise TypeError("Expected argument 'status' to be a int")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def events(self) -> Sequence['outputs.GetEventEventResult']:
        """
        List of Audit Trail events matching the requested criteria.
        """
        return pulumi.get(self, "events")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="methodName")
    def method_name(self) -> Optional[_builtins.str]:
        """
        API method called to trigger the event.
        """
        return pulumi.get(self, "method_name")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "order_by")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        ID of the Organization containing the Audit Trail events. (UUID format)
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[_builtins.str]:
        """
        ID of the user or IAM application at the origin of the event.
        """
        return pulumi.get(self, "principal_id")

    @_builtins.property
    @pulumi.getter(name="productName")
    def product_name(self) -> Optional[_builtins.str]:
        """
        Scaleway product associated with the listed events in a hyphenated format. Possible values are: `secret-manager`, `key-manager`, `iam`, `kubernetes`, `account`, `apple-silicon`, `instance`, `baremetal`, `load-balancer`, or `edge-services`.
        """
        return pulumi.get(self, "product_name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project of the resource attached to the event. (UUID format)
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="recordedAfter")
    def recorded_after(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "recorded_after")

    @_builtins.property
    @pulumi.getter(name="recordedBefore")
    def recorded_before(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "recorded_before")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "resource_id")

    @_builtins.property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "resource_type")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[_builtins.str]:
        """
        API name called to trigger the event. Possible values are: `scaleway.secret_manager.v1beta1.Api`, `scaleway.key_manager.v1alpha1.Api`, `scaleway.iam.v1alpha1.Api`, `scaleway.iam.v1alpha1.UnauthenticatedApi`, `scaleway.k8s.v1.Api`, `scaleway.account.v3.UserApi`, `scaleway.account.v3.OrganizationApi`, `scaleway.account.v2.GDPRApi`, `scaleway.apple_silicon.v1alpha1.Api`, `scaleway.instance.v1.Api`, `scaleway.baremetal.v1.Api`, or `scaleway.lb.v1.ZonedApi`.
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter(name="sourceIp")
    def source_ip(self) -> Optional[_builtins.str]:
        """
        IP address at the origin of the event. (IP address)
        """
        return pulumi.get(self, "source_ip")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "status")


class AwaitableGetEventResult(GetEventResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEventResult(
            events=self.events,
            id=self.id,
            method_name=self.method_name,
            order_by=self.order_by,
            organization_id=self.organization_id,
            principal_id=self.principal_id,
            product_name=self.product_name,
            project_id=self.project_id,
            recorded_after=self.recorded_after,
            recorded_before=self.recorded_before,
            region=self.region,
            resource_id=self.resource_id,
            resource_type=self.resource_type,
            service_name=self.service_name,
            source_ip=self.source_ip,
            status=self.status)


def get_event(method_name: Optional[_builtins.str] = None,
              order_by: Optional[_builtins.str] = None,
              organization_id: Optional[_builtins.str] = None,
              principal_id: Optional[_builtins.str] = None,
              product_name: Optional[_builtins.str] = None,
              project_id: Optional[_builtins.str] = None,
              recorded_after: Optional[_builtins.str] = None,
              recorded_before: Optional[_builtins.str] = None,
              region: Optional[_builtins.str] = None,
              resource_id: Optional[_builtins.str] = None,
              resource_type: Optional[_builtins.str] = None,
              service_name: Optional[_builtins.str] = None,
              source_ip: Optional[_builtins.str] = None,
              status: Optional[_builtins.int] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEventResult:
    """
    The `audittrail_get_event` data source is used to retrieve information about existing Audit Trail events.

    Refer to the Audit Trail [documentation](https://www.scaleway.com/en/docs/audit-trail/) and [API documentation](https://www.scaleway.com/en/developers/api/audit-trail/) for more information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail for a specific resource
    find_by_resource_id = scaleway.audittrail.get_event(resource_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve all audit trail events on the default organization
    find_all = scaleway.audittrail.get_event()
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail for a specific Scaleway product
    find_by_product_name = scaleway.audittrail.get_event(product_name="secret-manager")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail events with various filtering
    find_with_filters = scaleway.audittrail.get_event(region="fr-par",
        service_name="instance",
        method_name="CreateServer",
        principal_id="11111111-1111-1111-1111-111111111111",
        source_ip="192.0.2.1",
        status=200,
        recorded_after="2025-10-01T00:00:00Z",
        recorded_before="2025-12-31T23:59:59Z",
        order_by="recorded_at_desc")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail events on a specific organization
    find_by_org = scaleway.audittrail.get_event(organization_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail events on a specific project
    find_by_project = scaleway.audittrail.get_event(project_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail events for a specific type of resource
    find_by_resource_type = scaleway.audittrail.get_event(resource_type="instance_server")
    ```


    :param _builtins.str method_name: Name of the method of the API call performed.
    :param _builtins.str order_by: Defines the order in which events are returned. Possible values are `recorded_at_asc` and `recorded_at_desc`. Default value: `recorded_at_desc`.
    :param _builtins.str organization_id: `organization_id`) ID of the Organization containing the Audit Trail events.
    :param _builtins.str principal_id: ID of the User or IAM application at the origin of the event.
    :param _builtins.str product_name: Name of the Scaleway product in a hyphenated format.
    :param _builtins.str project_id: ID of the Project containing the Audit Trail events.
    :param _builtins.str recorded_after: The `recorded_after` parameter defines the earliest timestamp from which Audit Trail events are retrieved. Returns `one hour ago` by default (Format ISO 8601).
    :param _builtins.str recorded_before: The `recorded_before` parameter defines the latest timestamp up to which Audit Trail events are retrieved. Must be later than recorded_after. Returns `now` by default (Format ISO 8601).
    :param _builtins.str region: The region you want to target. Defaults to the region specified in the provider configuration.
    :param _builtins.str resource_id: ID of the Scaleway resource associated with the listed events.
    :param _builtins.str resource_type: Type of the scaleway resources associated with the listed events. Possible values are: `secm_secret`, `secm_secret_version`, `kube_cluster`, `kube_pool`, `kube_node`, `kube_acl`, `keym_key`, `iam_user`, `iam_application`, `iam_group`, `iam_policy`, `iam_api_key`, `iam_ssh_key`, `iam_rule`, `iam_saml`, `iam_saml_certificate`, `secret_manager_secret`, `secret_manager_version`, `key_manager_key`, `account_user`, `account_organization`, `account_project`, `instance_server`, `instance_placement_group`, `instance_security_group`, `instance_volume`, `instance_snapshot`, `instance_image`, `apple_silicon_server`, `baremetal_server`, `baremetal_setting`, `ipam_ip`, `sbs_volume`, `sbs_snapshot`, `load_balancer_lb`, `load_balancer_ip`, `load_balancer_frontend`, `load_balancer_backend`, `load_balancer_route`, `load_balancer_acl`, `load_balancer_certificate`, `sfs_filesystem`, or `vpc_private_network`.
    :param _builtins.str service_name: Name of the service of the API call performed.
    :param _builtins.str source_ip: IP address at the origin of the event.
    :param _builtins.int status: HTTP status code of the request.
    """
    __args__ = dict()
    __args__['methodName'] = method_name
    __args__['orderBy'] = order_by
    __args__['organizationId'] = organization_id
    __args__['principalId'] = principal_id
    __args__['productName'] = product_name
    __args__['projectId'] = project_id
    __args__['recordedAfter'] = recorded_after
    __args__['recordedBefore'] = recorded_before
    __args__['region'] = region
    __args__['resourceId'] = resource_id
    __args__['resourceType'] = resource_type
    __args__['serviceName'] = service_name
    __args__['sourceIp'] = source_ip
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:audittrail/getEvent:getEvent', __args__, opts=opts, typ=GetEventResult).value

    return AwaitableGetEventResult(
        events=pulumi.get(__ret__, 'events'),
        id=pulumi.get(__ret__, 'id'),
        method_name=pulumi.get(__ret__, 'method_name'),
        order_by=pulumi.get(__ret__, 'order_by'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        principal_id=pulumi.get(__ret__, 'principal_id'),
        product_name=pulumi.get(__ret__, 'product_name'),
        project_id=pulumi.get(__ret__, 'project_id'),
        recorded_after=pulumi.get(__ret__, 'recorded_after'),
        recorded_before=pulumi.get(__ret__, 'recorded_before'),
        region=pulumi.get(__ret__, 'region'),
        resource_id=pulumi.get(__ret__, 'resource_id'),
        resource_type=pulumi.get(__ret__, 'resource_type'),
        service_name=pulumi.get(__ret__, 'service_name'),
        source_ip=pulumi.get(__ret__, 'source_ip'),
        status=pulumi.get(__ret__, 'status'))
def get_event_output(method_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     organization_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     principal_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     product_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     recorded_after: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     recorded_before: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     resource_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     resource_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     service_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     source_ip: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     status: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEventResult]:
    """
    The `audittrail_get_event` data source is used to retrieve information about existing Audit Trail events.

    Refer to the Audit Trail [documentation](https://www.scaleway.com/en/docs/audit-trail/) and [API documentation](https://www.scaleway.com/en/developers/api/audit-trail/) for more information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail for a specific resource
    find_by_resource_id = scaleway.audittrail.get_event(resource_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve all audit trail events on the default organization
    find_all = scaleway.audittrail.get_event()
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail for a specific Scaleway product
    find_by_product_name = scaleway.audittrail.get_event(product_name="secret-manager")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail events with various filtering
    find_with_filters = scaleway.audittrail.get_event(region="fr-par",
        service_name="instance",
        method_name="CreateServer",
        principal_id="11111111-1111-1111-1111-111111111111",
        source_ip="192.0.2.1",
        status=200,
        recorded_after="2025-10-01T00:00:00Z",
        recorded_before="2025-12-31T23:59:59Z",
        order_by="recorded_at_desc")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail events on a specific organization
    find_by_org = scaleway.audittrail.get_event(organization_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail events on a specific project
    find_by_project = scaleway.audittrail.get_event(project_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve audit trail events for a specific type of resource
    find_by_resource_type = scaleway.audittrail.get_event(resource_type="instance_server")
    ```


    :param _builtins.str method_name: Name of the method of the API call performed.
    :param _builtins.str order_by: Defines the order in which events are returned. Possible values are `recorded_at_asc` and `recorded_at_desc`. Default value: `recorded_at_desc`.
    :param _builtins.str organization_id: `organization_id`) ID of the Organization containing the Audit Trail events.
    :param _builtins.str principal_id: ID of the User or IAM application at the origin of the event.
    :param _builtins.str product_name: Name of the Scaleway product in a hyphenated format.
    :param _builtins.str project_id: ID of the Project containing the Audit Trail events.
    :param _builtins.str recorded_after: The `recorded_after` parameter defines the earliest timestamp from which Audit Trail events are retrieved. Returns `one hour ago` by default (Format ISO 8601).
    :param _builtins.str recorded_before: The `recorded_before` parameter defines the latest timestamp up to which Audit Trail events are retrieved. Must be later than recorded_after. Returns `now` by default (Format ISO 8601).
    :param _builtins.str region: The region you want to target. Defaults to the region specified in the provider configuration.
    :param _builtins.str resource_id: ID of the Scaleway resource associated with the listed events.
    :param _builtins.str resource_type: Type of the scaleway resources associated with the listed events. Possible values are: `secm_secret`, `secm_secret_version`, `kube_cluster`, `kube_pool`, `kube_node`, `kube_acl`, `keym_key`, `iam_user`, `iam_application`, `iam_group`, `iam_policy`, `iam_api_key`, `iam_ssh_key`, `iam_rule`, `iam_saml`, `iam_saml_certificate`, `secret_manager_secret`, `secret_manager_version`, `key_manager_key`, `account_user`, `account_organization`, `account_project`, `instance_server`, `instance_placement_group`, `instance_security_group`, `instance_volume`, `instance_snapshot`, `instance_image`, `apple_silicon_server`, `baremetal_server`, `baremetal_setting`, `ipam_ip`, `sbs_volume`, `sbs_snapshot`, `load_balancer_lb`, `load_balancer_ip`, `load_balancer_frontend`, `load_balancer_backend`, `load_balancer_route`, `load_balancer_acl`, `load_balancer_certificate`, `sfs_filesystem`, or `vpc_private_network`.
    :param _builtins.str service_name: Name of the service of the API call performed.
    :param _builtins.str source_ip: IP address at the origin of the event.
    :param _builtins.int status: HTTP status code of the request.
    """
    __args__ = dict()
    __args__['methodName'] = method_name
    __args__['orderBy'] = order_by
    __args__['organizationId'] = organization_id
    __args__['principalId'] = principal_id
    __args__['productName'] = product_name
    __args__['projectId'] = project_id
    __args__['recordedAfter'] = recorded_after
    __args__['recordedBefore'] = recorded_before
    __args__['region'] = region
    __args__['resourceId'] = resource_id
    __args__['resourceType'] = resource_type
    __args__['serviceName'] = service_name
    __args__['sourceIp'] = source_ip
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:audittrail/getEvent:getEvent', __args__, opts=opts, typ=GetEventResult)
    return __ret__.apply(lambda __response__: GetEventResult(
        events=pulumi.get(__response__, 'events'),
        id=pulumi.get(__response__, 'id'),
        method_name=pulumi.get(__response__, 'method_name'),
        order_by=pulumi.get(__response__, 'order_by'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        principal_id=pulumi.get(__response__, 'principal_id'),
        product_name=pulumi.get(__response__, 'product_name'),
        project_id=pulumi.get(__response__, 'project_id'),
        recorded_after=pulumi.get(__response__, 'recorded_after'),
        recorded_before=pulumi.get(__response__, 'recorded_before'),
        region=pulumi.get(__response__, 'region'),
        resource_id=pulumi.get(__response__, 'resource_id'),
        resource_type=pulumi.get(__response__, 'resource_type'),
        service_name=pulumi.get(__response__, 'service_name'),
        source_ip=pulumi.get(__response__, 'source_ip'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BlockedListArgs', 'BlockedList']

@pulumi.input_type
class BlockedListArgs:
    def __init__(__self__, *,
                 domain_id: pulumi.Input[_builtins.str],
                 email: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a BlockedList resource.
        :param pulumi.Input[_builtins.str] domain_id: The ID of the domain affected by the blocklist. Must be in the format `{region}/{domain_id}`.
        :param pulumi.Input[_builtins.str] email: The email address to block.
        :param pulumi.Input[_builtins.str] type: Type of the blocklist. Possible values are:
        :param pulumi.Input[_builtins.str] project_id: The ID of the project this blocklist belongs to. Defaults to the provider's project ID.
        :param pulumi.Input[_builtins.str] reason: Reason for blocking the email address.
        :param pulumi.Input[_builtins.str] region: The region in which the blocklist is created. Defaults to the provider's region.
        """
        pulumi.set(__self__, "domain_id", domain_id)
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "type", type)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if reason is not None:
            pulumi.set(__self__, "reason", reason)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the domain affected by the blocklist. Must be in the format `{region}/{domain_id}`.
        """
        return pulumi.get(self, "domain_id")

    @domain_id.setter
    def domain_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "domain_id", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Input[_builtins.str]:
        """
        The email address to block.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of the blocklist. Possible values are:
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project this blocklist belongs to. Defaults to the provider's project ID.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def reason(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reason for blocking the email address.
        """
        return pulumi.get(self, "reason")

    @reason.setter
    def reason(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reason", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which the blocklist is created. Defaults to the provider's region.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _BlockedListState:
    def __init__(__self__, *,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering BlockedList resources.
        :param pulumi.Input[_builtins.str] domain_id: The ID of the domain affected by the blocklist. Must be in the format `{region}/{domain_id}`.
        :param pulumi.Input[_builtins.str] email: The email address to block.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project this blocklist belongs to. Defaults to the provider's project ID.
        :param pulumi.Input[_builtins.str] reason: Reason for blocking the email address.
        :param pulumi.Input[_builtins.str] region: The region in which the blocklist is created. Defaults to the provider's region.
        :param pulumi.Input[_builtins.str] type: Type of the blocklist. Possible values are:
        """
        if domain_id is not None:
            pulumi.set(__self__, "domain_id", domain_id)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if reason is not None:
            pulumi.set(__self__, "reason", reason)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the domain affected by the blocklist. Must be in the format `{region}/{domain_id}`.
        """
        return pulumi.get(self, "domain_id")

    @domain_id.setter
    def domain_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain_id", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The email address to block.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project this blocklist belongs to. Defaults to the provider's project ID.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def reason(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reason for blocking the email address.
        """
        return pulumi.get(self, "reason")

    @reason.setter
    def reason(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reason", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which the blocklist is created. Defaults to the provider's region.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the blocklist. Possible values are:
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("scaleway:tem/blockedList:BlockedList")
class BlockedList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages blocklisted email addresses for a Scaleway Transactional Email Domain.
        For more information refer to the [API documentation](https://www.scaleway.com/en/developers/api/transactional-email/#post-transactional-email-v1alpha1-regions-region-blocklists).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.tem.BlockedList("test",
            domain_id="fr-par/12345678-1234-1234-1234-123456789abc",
            email="spam@example.com",
            type="mailbox_full",
            reason="Spam detected",
            region="fr-par")
        ```

        ## Import

        Blocklists can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:tem/blockedList:BlockedList test fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain_id: The ID of the domain affected by the blocklist. Must be in the format `{region}/{domain_id}`.
        :param pulumi.Input[_builtins.str] email: The email address to block.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project this blocklist belongs to. Defaults to the provider's project ID.
        :param pulumi.Input[_builtins.str] reason: Reason for blocking the email address.
        :param pulumi.Input[_builtins.str] region: The region in which the blocklist is created. Defaults to the provider's region.
        :param pulumi.Input[_builtins.str] type: Type of the blocklist. Possible values are:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BlockedListArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages blocklisted email addresses for a Scaleway Transactional Email Domain.
        For more information refer to the [API documentation](https://www.scaleway.com/en/developers/api/transactional-email/#post-transactional-email-v1alpha1-regions-region-blocklists).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.tem.BlockedList("test",
            domain_id="fr-par/12345678-1234-1234-1234-123456789abc",
            email="spam@example.com",
            type="mailbox_full",
            reason="Spam detected",
            region="fr-par")
        ```

        ## Import

        Blocklists can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:tem/blockedList:BlockedList test fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param BlockedListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BlockedListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 reason: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BlockedListArgs.__new__(BlockedListArgs)

            if domain_id is None and not opts.urn:
                raise TypeError("Missing required property 'domain_id'")
            __props__.__dict__["domain_id"] = domain_id
            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["reason"] = reason
            __props__.__dict__["region"] = region
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(BlockedList, __self__).__init__(
            'scaleway:tem/blockedList:BlockedList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain_id: Optional[pulumi.Input[_builtins.str]] = None,
            email: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            reason: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'BlockedList':
        """
        Get an existing BlockedList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain_id: The ID of the domain affected by the blocklist. Must be in the format `{region}/{domain_id}`.
        :param pulumi.Input[_builtins.str] email: The email address to block.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project this blocklist belongs to. Defaults to the provider's project ID.
        :param pulumi.Input[_builtins.str] reason: Reason for blocking the email address.
        :param pulumi.Input[_builtins.str] region: The region in which the blocklist is created. Defaults to the provider's region.
        :param pulumi.Input[_builtins.str] type: Type of the blocklist. Possible values are:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BlockedListState.__new__(_BlockedListState)

        __props__.__dict__["domain_id"] = domain_id
        __props__.__dict__["email"] = email
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["reason"] = reason
        __props__.__dict__["region"] = region
        __props__.__dict__["type"] = type
        return BlockedList(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the domain affected by the blocklist. Must be in the format `{region}/{domain_id}`.
        """
        return pulumi.get(self, "domain_id")

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Output[_builtins.str]:
        """
        The email address to block.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the project this blocklist belongs to. Defaults to the provider's project ID.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def reason(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Reason for blocking the email address.
        """
        return pulumi.get(self, "reason")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The region in which the blocklist is created. Defaults to the provider's region.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of the blocklist. Possible values are:
        """
        return pulumi.get(self, "type")

